@@ -82,10 +82,10 @@ typedef struct _BraseroDvdcssPrivate BraseroDvdcssPrivate;
 static GObjectClass *parent_class = NULL;
 
 static gboolean
-brasero_dvdcss_library_init (GError **error)
+brasero_dvdcss_library_init (BraseroPlugin *plugin)
 {
-	GModule *module;
 	gpointer address;
+	GModule *module;
 	gchar *dvdcss_interface_2 = NULL;
 
 	if (css_ready)
@@ -98,53 +98,46 @@ brasero_dvdcss_library_init (GError **error)
 
 	if (!g_module_symbol (module, "dvdcss_interface_2", &address))
 		goto error_version;
-
 	dvdcss_interface_2 = address;
+
 	if (!g_module_symbol (module, "dvdcss_open", &address))
-		goto error_loading;
+		goto error_version;
 	dvdcss_open = address;
 
 	if (!g_module_symbol (module, "dvdcss_close", &address))
-		goto error_loading;
+		goto error_version;
 	dvdcss_close = address;
 
 	if (!g_module_symbol (module, "dvdcss_read", &address))
-		goto error_loading;
+		goto error_version;
 	dvdcss_read = address;
 
 	if (!g_module_symbol (module, "dvdcss_seek", &address))
-		goto error_loading;
+		goto error_version;
 	dvdcss_seek = address;
 
 	if (!g_module_symbol (module, "dvdcss_error", &address))
-		goto error_loading;
+		goto error_version;
 	dvdcss_error = address;
 
+	if (plugin) {
+		g_module_close (module);
+		return TRUE;
+	}
+
 	css_ready = TRUE;
 	return TRUE;
 
 error_doesnt_exist:
-	g_set_error (error,
-		     BRASERO_BURN_ERROR,
-		     BRASERO_BURN_ERROR_GENERAL,
-		     _("Encrypted DVD: please install libdvdcss version 1.2.x"));
+	brasero_plugin_add_error (plugin,
+	                          BRASERO_PLUGIN_ERROR_MISSING_LIBRARY,
+	                          "libdvdcss.so.2");
 	return FALSE;
 
 error_version:
-	g_set_error (error,
-		     BRASERO_BURN_ERROR,
-		     BRASERO_BURN_ERROR_GENERAL,
-		     _("libdvdcss version %s is not supported.\nPlease install libdvdcss version 1.2.x"),
-		     dvdcss_interface_2);
-	g_module_close (module);
-	return FALSE;
-
-
-error_loading:
-	g_set_error (error,
-		     BRASERO_BURN_ERROR,
-		     BRASERO_BURN_ERROR_GENERAL,
-		     _("libdvdcss could not be loaded properly"));
+	brasero_plugin_add_error (plugin,
+	                          BRASERO_PLUGIN_ERROR_LIBRARY_VERSION,
+	                          "libdvdcss.so.2");
 	g_module_close (module);
 	return FALSE;
 }
@@ -263,12 +256,12 @@ brasero_dvdcss_create_scrambled_sectors_map (GQueue *map,
 				BraseroScrambledSectorRange *range;
 				GSList *extents;
 
-				range = g_new0 (BraseroScrambledSectorRange, 1);
-
 				/* take the first address for each extent of the file */
 				if (!file->specific.file.extents)
 					return FALSE;
 
+				range = g_new0 (BraseroScrambledSectorRange, 1);
+				
 				for (extents = file->specific.file.extents; extents; extents = extents->next) {
 					BraseroVolFileExtent *extent;
 
@@ -282,7 +275,7 @@ brasero_dvdcss_create_scrambled_sectors_map (GQueue *map,
 						g_set_error (error,
 							     BRASERO_BURN_ERROR,
 							     BRASERO_BURN_ERROR_GENERAL,
-							     _("Error reading video DVD (%s)"),
+							     _("Error while reading video DVD (%s)"),
 							     dvdcss_error (handle));
 						return FALSE;
 					}
@@ -388,7 +381,7 @@ brasero_dvdcss_write_image_thread (gpointer data)
 
 	brasero_job_set_current_action (BRASERO_JOB (self),
 					BRASERO_BURN_ACTION_DRIVE_COPY,
-					_("Copying Video DVD"),
+					_("Copying video DVD"),
 					FALSE);
 
 	brasero_job_start_progress (BRASERO_JOB (self), TRUE);
@@ -565,7 +558,7 @@ brasero_dvdcss_start (BraseroJob *job,
 	if (priv->thread)
 		return BRASERO_BURN_RUNNING;
 
-	if (!brasero_dvdcss_library_init (error))
+	if (!brasero_dvdcss_library_init (NULL))
 		return BRASERO_BURN_ERR;
 
 	g_mutex_lock (priv->mutex);
@@ -672,28 +665,19 @@ brasero_dvdcss_finalize (GObject *object)
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static BraseroBurnResult
-brasero_dvdcss_export_caps (BraseroPlugin *plugin, gchar **error)
+static void
+brasero_dvdcss_export_caps (BraseroPlugin *plugin)
 {
-	GError *gerror = NULL;
 	GSList *output;
 	GSList *input;
 
 	brasero_plugin_define (plugin,
 			       "dvdcss",
-			       _("dvdcss allows to CSS-encrypted video DVDs to be read"),
+	                       NULL,
+			       _("Copies CSS encrypted video DVDs to a disc image"),
 			       "Philippe Rouquier",
 			       0);
 
-	/* see if libdvdcss can be initted */
-	if (!brasero_dvdcss_library_init (&gerror)) {
-		if (gerror) {
-			*error = g_strdup (gerror->message);
-			g_error_free (gerror);
-		}
-		return BRASERO_BURN_ERR;
-	}
-
 	/* to my knowledge, css can only be applied to pressed discs so no need
 	 * to specify anything else but ROM */
 	output = brasero_caps_image_new (BRASERO_PLUGIN_IO_ACCEPT_FILE|
@@ -710,6 +694,10 @@ brasero_dvdcss_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	g_slist_free (input);
 	g_slist_free (output);
+}
 
-	return BRASERO_BURN_OK;
+G_MODULE_EXPORT void
+brasero_plugin_check_config (BraseroPlugin *plugin)
+{
+	brasero_dvdcss_library_init (plugin);
 }
