@@ -30,8 +30,6 @@
 
 #include <gtk/gtk.h>
 
-#include <unique/unique.h>
-
 #include "brasero-misc.h"
 #include "brasero-io.h"
 
@@ -64,10 +62,13 @@
 #include "brasero-jacket-edit.h"
 
 #include "burn-plugin-manager.h"
+#include "brasero-drive-settings.h"
 
 typedef struct _BraseroAppPrivate BraseroAppPrivate;
 struct _BraseroAppPrivate
 {
+	GApplication *gapp;
+
 	BraseroSetting *setting;
 
 	GdkWindow *parent;
@@ -99,6 +100,11 @@ struct _BraseroAppPrivate
 
 G_DEFINE_TYPE (BraseroApp, brasero_app, G_TYPE_OBJECT);
 
+enum {
+	PROP_NONE,
+	PROP_GAPP
+};
+
 /**
  * Menus and toolbar
  */
@@ -420,15 +426,6 @@ brasero_app_alert (BraseroApp *app,
 	gtk_widget_destroy (alert);
 }
 
-GtkUIManager *
-brasero_app_get_ui_manager (BraseroApp *app)
-{
-	BraseroAppPrivate *priv;
-
-	priv = BRASERO_APP_PRIVATE (app);
-	return priv->manager;
-}
-
 GtkWidget *
 brasero_app_get_statusbar1 (BraseroApp *app)
 {
@@ -549,7 +546,7 @@ brasero_app_burn (BraseroApp *app,
 	return success;
 }
 
-gboolean
+static BraseroBurnResult
 brasero_app_burn_options (BraseroApp *app,
 			  BraseroSessionCfg *session)
 {
@@ -579,6 +576,13 @@ brasero_app_session_burn (BraseroApp *app,
 			  BraseroSessionCfg *session,
 			  gboolean burn)
 {
+	BraseroDriveSettings *settings;
+
+	/* Set saved temporary directory for the session.
+	 * NOTE: BraseroBurnSession can cope with NULL path */
+	settings = brasero_drive_settings_new ();
+	brasero_drive_settings_set_session (settings, BRASERO_BURN_SESSION (session));
+
 	/* We need to have a drive to start burning immediately */
 	if (burn && brasero_burn_session_get_burner (BRASERO_BURN_SESSION (session))) {
 		BraseroStatus *status;
@@ -600,8 +604,10 @@ brasero_app_session_burn (BraseroApp *app,
 		}
 		g_object_unref (status);
 
-		if (result == BRASERO_BURN_CANCEL)
+		if (result == BRASERO_BURN_CANCEL) {
+			g_object_unref (settings);
 			return;
+		}
 
 		if (result != BRASERO_BURN_OK) {
 			GError *error;
@@ -614,18 +620,26 @@ brasero_app_session_burn (BraseroApp *app,
 			if (error)
 				g_error_free (error);
 
+			g_object_unref (settings);
 			return;
 		}
 
-		brasero_app_burn (app, BRASERO_BURN_SESSION (session), FALSE);
+		result = brasero_app_burn (app,
+		                           BRASERO_BURN_SESSION (session),
+		                           FALSE);
 	}
 	else {
 		BraseroBurnResult result;
 
 		result = brasero_app_burn_options (app, session);
-		if (result == BRASERO_BURN_OK || result == BRASERO_BURN_RETRY)
-			brasero_app_burn (app, BRASERO_BURN_SESSION (session), (result == BRASERO_BURN_RETRY));
+		if (result == BRASERO_BURN_OK || result == BRASERO_BURN_RETRY) {
+			result = brasero_app_burn (app,
+			                           BRASERO_BURN_SESSION (session),
+			                           (result == BRASERO_BURN_RETRY));
+		}
 	}
+
+	g_object_unref (settings);
 }
 
 void
@@ -1985,58 +1999,42 @@ brasero_app_create_mainwin (BraseroApp *app)
 	brasero_app_load_window_state (app);
 }
 
-static UniqueResponse
-brasero_app_unique_message (UniqueApp *uapp,
-			    gint command,
-			    UniqueMessageData *message_data,
-			    guint time,
-			    BraseroApp *app)
+static void
+brasero_app_prepare_activation (GApplication *gapp,
+                                GVariant *arguments,
+                                GVariant *platform_data,
+                                BraseroApp *app)
 {
 	BraseroAppPrivate *priv;
 
 	priv = BRASERO_APP_PRIVATE (app);
-	if (command == UNIQUE_ACTIVATE) {
-		if (priv->mainwin_running) {
-			gtk_widget_show (priv->mainwin);
-			gtk_window_present (GTK_WINDOW (priv->mainwin));
-		}
-	}
 
-	return UNIQUE_RESPONSE_OK;
+	/* Except if we are supposed to quit show the window */
+	if (priv->mainwin_running) {
+		gtk_widget_show (priv->mainwin);
+		gtk_window_present (GTK_WINDOW (priv->mainwin));
+	}
 }
 
 gboolean
 brasero_app_run_mainwin (BraseroApp *app)
 {
 	BraseroAppPrivate *priv;
-	UniqueApp *uapp;
 
 	priv = BRASERO_APP_PRIVATE (app);
 
+	if (priv->mainwin_running)
+		return TRUE;
+
 	priv->mainwin_running = 1;
 	gtk_widget_show (GTK_WIDGET (priv->mainwin));
 
-	uapp = unique_app_new ("org.gnome.Brasero", NULL);
-	g_signal_connect (uapp,
-			  "message-received",
-			  G_CALLBACK (brasero_app_unique_message),
-			  app);
-
-	if (unique_app_is_running (uapp))
-	{
-		UniqueResponse response;
-
-		response = unique_app_send_message (uapp, UNIQUE_ACTIVATE, NULL);
-    		g_object_unref (uapp);
-		uapp = NULL;
-
-		/* FIXME: we should tell the user why it did not work. Or is it
-		 * handled by libunique? */
-		return (response == UNIQUE_RESPONSE_OK);
-	}
-
+	if (priv->gapp)
+		g_signal_connect (priv->gapp,
+				  "prepare-activation",
+				  G_CALLBACK (brasero_app_prepare_activation),
+				  app);
 	gtk_main ();
-
 	return TRUE;
 }
 
@@ -2100,6 +2098,51 @@ brasero_app_finalize (GObject *object)
 
 	G_OBJECT_CLASS (brasero_app_parent_class)->finalize (object);
 }
+static void
+brasero_app_set_property (GObject *object,
+                          guint prop_id,
+                          const GValue *value,
+                          GParamSpec *pspec)
+{
+	BraseroAppPrivate *priv;
+
+	g_return_if_fail (BRASERO_IS_APP (object));
+
+	priv = BRASERO_APP_PRIVATE (object);
+
+	switch (prop_id)
+	{
+	case PROP_GAPP:
+		priv->gapp = g_value_dup_object (value);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
+
+static void
+brasero_app_get_property (GObject *object,
+			  guint prop_id,
+			  GValue *value,
+			  GParamSpec *pspec)
+{
+	BraseroAppPrivate *priv;
+
+	g_return_if_fail (BRASERO_IS_APP (object));
+
+	priv = BRASERO_APP_PRIVATE (object);
+
+	switch (prop_id)
+	{
+	case PROP_GAPP:
+		g_value_set_object (value, priv->gapp);
+		break;
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+		break;
+	}
+}
 
 static void
 brasero_app_class_init (BraseroAppClass *klass)
@@ -2109,10 +2152,22 @@ brasero_app_class_init (BraseroAppClass *klass)
 	g_type_class_add_private (klass, sizeof (BraseroAppPrivate));
 
 	object_class->finalize = brasero_app_finalize;
+	object_class->set_property = brasero_app_set_property;
+	object_class->get_property = brasero_app_get_property;
+
+	g_object_class_install_property (object_class,
+	                                 PROP_GAPP,
+	                                 g_param_spec_object("gapp",
+	                                                     "GApplication",
+	                                                     "The GApplication object",
+	                                                     G_TYPE_APPLICATION,
+	                                                     G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 BraseroApp *
-brasero_app_new (void)
+brasero_app_new (GApplication *gapp)
 {
-	return g_object_new (BRASERO_TYPE_APP, NULL);
+	return g_object_new (BRASERO_TYPE_APP,
+	                     "gapp", gapp,
+	                     NULL);
 }
