@@ -749,7 +749,8 @@ brasero_audio_disc_add_dir (BraseroAudioDisc *disc, const gchar *uri)
 				     GTK_MESSAGE_WARNING);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("Directories cannot be added to an audio disc."));
+						  "%s.",
+						  _("Directories cannot be added to video or audio discs"));
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -1315,7 +1316,10 @@ brasero_audio_disc_split (BraseroAudioDisc *disc)
 	gtk_window_set_position (GTK_WINDOW (toplevel), GTK_WIN_POS_CENTER_ON_PARENT);
 
 	uri = brasero_track_stream_get_source (BRASERO_TRACK_STREAM (track), TRUE);
-	brasero_split_dialog_set_uri (BRASERO_SPLIT_DIALOG (dialog), uri);
+	brasero_split_dialog_set_uri (BRASERO_SPLIT_DIALOG (dialog),
+	                              uri,
+	                              brasero_track_tag_lookup_string (track, BRASERO_TRACK_STREAM_TITLE_TAG),
+	                              brasero_track_tag_lookup_string (track, BRASERO_TRACK_STREAM_ARTIST_TAG));
 	g_free (uri);
 
 	brasero_split_dialog_set_boundaries (BRASERO_SPLIT_DIALOG (dialog),
